@@ -1,6 +1,6 @@
 import argparse
 import subprocess
-from Accuinsight.modeler.clients.modeler_api import WorkspaceRunRestApi
+from Accuinsight.modeler.clients.modeler_api import WorkspaceRestApi
 from Accuinsight.modeler.entities.workspace_run_log import WorkspaceRunLog
 from Accuinsight.modeler.core.LcConst import LcConst
 from Accuinsight.modeler.utils.os_getenv import get_os_env
@@ -14,9 +14,9 @@ class WorkspaceRun:
         env_value = get_os_env('ENV')
 
         self.workspace_run_log = WorkspaceRunLog()
-        self.workspace_run_api = WorkspaceRunRestApi(env_value[LcConst.BACK_END_API_URL],
-                                                     env_value[LcConst.BACK_END_API_PORT],
-                                                     env_value[LcConst.BACK_END_API_URI])
+        self.workspace_run_api = WorkspaceRestApi(env_value[LcConst.BACK_END_API_URL],
+                                                  env_value[LcConst.BACK_END_API_PORT],
+                                                  env_value[LcConst.BACK_END_API_URI])
         self.code_path = None
 
     def exec_code(self):
@@ -46,7 +46,7 @@ class WorkspaceRun:
         except subprocess.CalledProcessError:
             self.workspace_run_log.is_success = False
         finally:
-            self.workspace_run_api.call_rest_api(self.workspace_run_log.get_result_param())
+            self.workspace_run_api.call_rest_api(self.workspace_run_log.get_result_param(), 'run')
 
 
 if __name__ == "__main__":
